@@ -20,22 +20,29 @@
 
 #include "coordinate_system.h"
 
-#include "../kig/kig_part.h"
+#include "../kig/kig_document.h"
 #include "../kig/kig_view.h"
 
-#include "i18n.h"
 #include "common.h"
 #include "coordinate.h"
+#include "goniometry.h"
 #include "kigpainter.h"
 
 #include <qpainter.h>
 #include <qregexp.h>
+
+#include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kdebug.h>
-#include <knumvalidator.h>
 #include <kmessagebox.h>
+#include <knumvalidator.h>
+#include <kdeversion.h>
+#if KDE_IS_VERSION( 3, 1, 90 )
+#include <kinputdialog.h>
+#else
 #include <klineeditdlg.h>
+#endif
+
 #include <string>
 #include <math.h>
 
@@ -202,6 +209,11 @@ void EuclideanCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) co
 {
   p.setWholeWinOverlay();
 
+  // this instruction in not necessary, but there is a little
+  // optimization when there are no grid and no axes.
+  if ( !( showgrid || showaxes ) )
+    return;
+
   // this function is inspired upon ( public domain ) code from the
   // first Graphics Gems book.  Credits to Paul S. Heckbert, who wrote
   // the "Nice number for graph labels" gem.
@@ -288,7 +300,8 @@ void EuclideanCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) co
     a.push_back( Coordinate( hmax - 6 * u, -3 * u) );
     a.push_back( Coordinate( hmax, 0 ) );
     a.push_back( Coordinate( hmax - 6 * u, 3 * u ) );
-    p.drawPolygon( a, true );
+    p.drawArea( a );
+//    p.drawPolygon( a, true );
 
     // the arrow on the top end of the Y axis...
     a.clear();
@@ -296,14 +309,15 @@ void EuclideanCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) co
     a.push_back( Coordinate( 3 * u, vmax - 6 * u ) );
     a.push_back( Coordinate( 0, vmax ) );
     a.push_back( Coordinate( -3 * u, vmax - 6 * u ) );
-    p.drawPolygon( a, true );
+    p.drawArea( a );
+//    p.drawPolygon( a, true );
   }; // if( showaxes )
 }
 
 QString EuclideanCoords::coordinateFormatNotice() const
 {
-  return i18n( "Enter coordinates in the following form: \"x;y\", where "
-               "x is the x coordinate, and y is the y coordinate." );
+  return i18n( "Enter coordinates in the following form: \"x;y\",\n"
+               "where x is the x coordinate, and y is the y coordinate." );
 }
 
 EuclideanCoords::~EuclideanCoords()
@@ -333,7 +347,7 @@ QString PolarCoords::fromScreen( const Coordinate& pt, const KigDocument& d ) co
   int l = kigMax( 0, (int) ( 3 - log10( m ) ) );
 
   double r = pt.length();
-  double theta = atan2( pt.y, pt.x ) * 180 / M_PI;
+  double theta = Goniometry::convert( atan2( pt.y, pt.x ), Goniometry::Rad, Goniometry::Deg );
 
   QString rs = KGlobal::locale()->formatNumber( r, l );
   QString ts = KGlobal::locale()->formatNumber( theta, 0 );
@@ -344,8 +358,8 @@ QString PolarCoords::fromScreen( const Coordinate& pt, const KigDocument& d ) co
 QString PolarCoords::coordinateFormatNotice() const
 {
   // \xCE\xB8 is utf8 for the greek theta sign..
-  return i18n( "Enter coordinates in the following form: \"r; \xCE\xB8°\", where "
-               "r and \xCE\xB8 are the polar coordinates." );
+  return i18n( "Enter coordinates in the following form: \"r; \xCE\xB8°\",\n"
+               "where r and \xCE\xB8 are the polar coordinates." );
 }
 
 Coordinate PolarCoords::toScreen(const QString& s, bool& ok) const
@@ -373,15 +387,19 @@ void PolarCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) const
 {
   p.setWholeWinOverlay();
 
+  // this instruction in not necessary, but there is a little
+  // optimization when there are no grid and no axes.
+  if ( !( showgrid || showaxes ) )
+    return;
+
   // we multiply by sqrt( 2 ) cause we don't want to miss circles in
   // the corners, that intersect with the axes outside of the
   // screen..
-  const double sqrt2 = 1.4142135623;
 
-  const double hmax = sqrt2*p.window().right();
-  const double hmin = sqrt2*p.window().left();
-  const double vmax = sqrt2*p.window().top();
-  const double vmin = sqrt2*p.window().bottom();
+  const double hmax = M_SQRT2*p.window().right();
+  const double hmin = M_SQRT2*p.window().left();
+  const double vmax = M_SQRT2*p.window().top();
+  const double vmin = M_SQRT2*p.window().bottom();
 
   // the intervals:
   // we try to have one of them per 40 pixels or so..
@@ -406,16 +424,18 @@ void PolarCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) const
   /****** the grid lines ******/
   if ( showgrid )
   {
-    double begin = kigMin( hgraphmin, vgraphmin );
-    double end = kigMax( hgraphmax, vgraphmax );
     double d = kigMin( hd, vd );
+    double begin = kigMin( kigAbs( hgraphmin ), kigAbs( vgraphmin ) );
+    if ( kigSgn( hgraphmin ) != kigSgn( hgraphmax ) && kigSgn( vgraphmin ) != kigSgn( vgraphmax ) )
+      begin = d;
+    double end = kigMax( hgraphmax, vgraphmax );
 
     // we also want the circles that don't fit entirely in the
     // screen..
     Coordinate c( 0, 0 );
     p.setPen( QPen( lightGray, 0, DotLine ) );
     for ( double i = begin; i <= end + d / 2; i += d )
-      p.drawCircle( c, fabs( i ) );
+      drawGridLine( p, c, fabs( i ) );
   }
 
   /****** the axes ******/
@@ -463,7 +483,8 @@ void PolarCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) const
     a.push_back( Coordinate( hmax - 6 * u, -3 * u) );
     a.push_back( Coordinate( hmax, 0 ) );
     a.push_back( Coordinate( hmax - 6 * u, 3 * u ) );
-    p.drawPolygon( a, true );
+//    p.drawPolygon( a, true );
+    p.drawArea( a );
 
     // the arrow on the top end of the Y axis...
     a.clear();
@@ -471,7 +492,8 @@ void PolarCoords::drawGrid( KigPainter& p, bool showgrid, bool showaxes ) const
     a.push_back( Coordinate( 3 * u, vmax - 6 * u ) );
     a.push_back( Coordinate( 0, vmax ) );
     a.push_back( Coordinate( -3 * u, vmax - 6 * u ) );
-    p.drawPolygon( a, true );
+//    p.drawPolygon( a, true );
+    p.drawArea( a );
   }; // if( showaxes )
 }
 
@@ -497,8 +519,11 @@ const Coordinate CoordinateSystem::getCoordFromUser( const QString& caption,
   while ( ! done )
   {
     QValidator* vtor = coordinateValidator();
-    value = KLineEditDlg::getText(
-      caption, label, value, ok, parent, vtor );
+#if KDE_IS_VERSION( 3, 1, 90 )
+    value = KInputDialog::getText( caption, label, value, ok, parent, 0, vtor );
+#else
+    value = KLineEditDlg::getText( caption, label, value, ok, parent, vtor );
+#endif
     delete vtor;
 
     if ( ! *ok ) return Coordinate();
@@ -506,7 +531,7 @@ const Coordinate CoordinateSystem::getCoordFromUser( const QString& caption,
     ret = toScreen( value, *ok );
     if ( *ok ) done = true;
     else
-      KMessageBox::sorry( parent, i18n( "The coordinate you entered was not valid. Please try again.") );
+      KMessageBox::sorry( parent, i18n( "The coordinates you entered was not valid. Please try again.") );
   };
   return ret;
 }
@@ -616,14 +641,13 @@ Coordinate PolarCoords::snapToGrid( const Coordinate& c,
   // we multiply by sqrt( 2 ) cause we don't want to miss circles in
   // the corners, that intersect with the axes outside of the
   // screen..
-  const double sqrt2 = 1.4142135623;
 
   Rect r = w.showingRect();
 
-  const double hmax = sqrt2 * r.right();
-  const double hmin = sqrt2 * r.left();
-  const double vmax = sqrt2 * r.top();
-  const double vmin = sqrt2 * r.bottom();
+  const double hmax = M_SQRT2 * r.right();
+  const double hmin = M_SQRT2 * r.left();
+  const double vmax = M_SQRT2 * r.top();
+  const double vmin = M_SQRT2 * r.bottom();
 
   // the intervals:
   // we try to have one of them per 40 pixels or so..
@@ -642,3 +666,75 @@ Coordinate PolarCoords::snapToGrid( const Coordinate& c,
   double ndist = qRound( dist / d ) * d;
   return c.normalize( ndist );
 }
+
+void PolarCoords::drawGridLine( KigPainter& p, const Coordinate& c,
+                                double r ) const
+{
+  Rect rect = p.window();
+
+  struct iterdata_t
+  {
+    int xd;
+    int yd;
+    Coordinate ( Rect::*point )() const;
+    Coordinate ( Rect::*oppositepoint )() const;
+    double horizAngle;
+    double vertAngle;
+  };
+
+  static const iterdata_t iterdata[] =
+    {
+      { +1, +1, &Rect::topRight, &Rect::bottomLeft, 0, M_PI/2 },
+      { -1, +1, &Rect::topLeft, &Rect::bottomRight, M_PI, M_PI / 2 },
+      { -1, -1, &Rect::bottomLeft, &Rect::topRight, M_PI, 3*M_PI/2 },
+      { +1, -1, &Rect::bottomRight, &Rect::topLeft, 2*M_PI, 3*M_PI/2 }
+    };
+  for ( int i = 0; i < 4; ++i )
+  {
+    int xd = iterdata[i].xd;
+    int yd = iterdata[i].yd;
+    Coordinate point = ( rect.*iterdata[i].point )();
+    Coordinate opppoint = ( rect.*iterdata[i].oppositepoint )();
+    double horizangle = iterdata[i].horizAngle;
+    double vertangle = iterdata[i].vertAngle;
+
+    if ( ( c.x - point.x )*xd > 0 || ( c.y - point.y )*yd > 0 )
+      continue;
+    if ( ( c.x - opppoint.x )*-xd > r || ( c.y - opppoint.y )*-yd > r )
+      continue;
+
+    int posdir = xd*yd;
+    double hd = ( point.x - c.x )*xd;
+    assert( hd >= 0 );
+    if ( hd < r )
+    {
+      double anglediff = acos( hd/r );
+      horizangle += posdir * anglediff;
+    }
+
+    hd = ( c.x - opppoint.x )*-xd;
+    if ( hd >= 0 )
+    {
+      double anglediff = asin( hd/r );
+      vertangle -= posdir * anglediff;
+    }
+
+    double vd = ( point.y - c.y )*yd;
+    assert( vd >= 0 );
+    if ( vd < r )
+    {
+      double anglediff = acos( vd/r );
+      vertangle -= posdir * anglediff;
+    }
+
+    vd = ( c.y - opppoint.y ) * -xd;
+    if ( vd >= 0 )
+    {
+      double anglediff = asin( hd/r );
+      horizangle += posdir * anglediff;
+    }
+
+    p.drawArc( c, r, kigMin( horizangle, vertangle ), kigMax( horizangle, vertangle ) );
+  }
+//  p.drawCircle( c, r );
+}
