@@ -38,6 +38,7 @@ class Transformation
 {
   double mdata[3][3];
   bool mIsHomothety;
+  bool mIsAffine;
   Transformation();
 public:
   ~Transformation();
@@ -46,13 +47,19 @@ public:
   /**
    * Apply this Tranformation.  Apply this transformation to the
    * Coordinate c.  Can return an invalid Coordinate.
+   * apply0 assumes that c indicates a point at infinity, having
+   * [0, c.x, c.y] as homogeneous coordinates
    */
+  const Coordinate apply( const double x0, const double x1, const double x2 ) const;
   const Coordinate apply( const Coordinate& c ) const;
+  const Coordinate apply0( const Coordinate& c ) const;
 
   /**
-   * Returns whether this is a homothetic transformation.
+   * Returns whether this is a homothetic (affine) transformation.
    */
   bool isHomothetic() const;
+  bool isAffine() const;
+  double getProjectiveIndicator( const Coordinate& c ) const;
   double getAffineDeterminant() const;
   double getRotationAngle() const;
   const Coordinate apply2by2only( const Coordinate& c ) const;
