@@ -2,7 +2,7 @@
                           minparser.cpp  -  description
                              -------------------
     begin                : Thu Mar 28 2002
-    copyright            : (C) 2002 by Primoz Anzur (zer0Kode)
+    copyright            : (C) 2002 by Primoz Anzur 
     email                : zerokode@gmx.net
  ***************************************************************************/
 
@@ -43,7 +43,7 @@ QString MinParser::getSingleRow(int row)
 	return word;
 }
 
-QString MinParser::getItem(int row, int item, QString delimiter)
+QString MinParser::getItem(int row, int item, const QString &delimiter)
 {
 	if (! getSingleRow(row))
 		return 0L; //return null instantly, if the line is empty...
@@ -58,13 +58,13 @@ int MinParser::rows()
 	return allData.count();
 }
 
-int MinParser::objects(int row, QString delimiter)
+int MinParser::objects(int row, const QString &delimiter)
 {
 	QStringList objData=QStringList::split(delimiter, getSingleRow(row));
 	return objData.count();
 }
 
-void MinParser::loadFile(QString sFile)
+void MinParser::loadFile(const QString &sFile)
 {
 	QFile openDataFile(sFile);
 	openDataFile.open(IO_ReadOnly);
@@ -73,7 +73,7 @@ void MinParser::loadFile(QString sFile)
 	openDataFile.close();
 }
 
-QString MinParser::getClean(int row, QString delimiter)
+QString MinParser::getClean(int row, const QString &delimiter)
 {
 	QStringList objData=QStringList::split(delimiter, getSingleRow(row));
 	QString saneData;
@@ -85,7 +85,7 @@ QString MinParser::getClean(int row, QString delimiter)
 		//OK... That was kind of a bad idea... We should actually
 		//answer in normal word, not with syllables...
 /*
-		if (saneData=="")
+		if (saneData.isEmpty())
 			saneData=saneData+sd;
 		else
 			saneData=saneData+"-"+sd;
@@ -94,7 +94,7 @@ QString MinParser::getClean(int row, QString delimiter)
 	return saneData;
 }
 
-QString MinParser::makeMess(int row, QString delimiter)
+QString MinParser::makeMess(int row, const QString &delimiter)
 {
 	QStringList objData=QStringList::split(delimiter, getSingleRow(row));
 	QString insaneData;
