@@ -35,9 +35,9 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
+#include <zlib.h>
 
 #include "webcam/QCamV4L.h"
-#include "lzo/minilzo.h"
 #include "indidevapi.h"
 #include "indicom.h"
 #include "fitsrw.h"
@@ -51,8 +51,8 @@ void waitForData(int rp, int wp);
 void updateDataChannel(void *p);
 void updateStream(void * p);
 void getBasicData(void);
-void uploadFile(char * filename);
-int  writeFITS(char *filename, char errmsg[]);
+void uploadFile(const char * filename);
+int  writeFITS(const char *filename, char errmsg[]);
 int  grabImage(void);
 int  checkPowerN(INumberVectorProperty *np);
 int  checkPowerS(ISwitchVectorProperty *sp);
@@ -80,11 +80,6 @@ extern int errno;
 #define PIPEBUFSIZ	8192
 #define FRAME_ILEN	64
 
-#define HEAP_ALLOC(var,size) \
-	lzo_align_t __LZO_MMODEL var [ ((size) + (sizeof(lzo_align_t) - 1)) / sizeof(lzo_align_t) ]
-
-static HEAP_ALLOC(wrkmem,LZO1X_1_MEM_COMPRESS);
-
 typedef struct {
 int  width;
 int  height;
@@ -183,9 +178,6 @@ void ISInit()
  INDIClients = NULL;
  nclients    = 0;
  
- if (lzo_init() != LZO_E_OK)
-   IDLog("lzo_init() failed !!!\n");
-      
  isInit = 1;
 
 }
@@ -461,14 +453,14 @@ void ISNewNumber (const char *dev, const char *name, double values[], char *name
 int grabImage()
 {
    int err, fd;
-   char errmsg[1024];
+   char errmsg[ERRMSG_SIZE];
    char filename[] = "/tmp/fitsXXXXXX";
   
    
    if ((fd = mkstemp(filename)) < 0)
    { 
-    IDMessage(mydev, "Error making temporary filename.", NULL);
-    IDLog("Error making temporary filename.\n", NULL);
+    IDMessage(mydev, "Error making temporary filename.");
+    IDLog("Error making temporary filename.\n");
     return -1;
    }
    close(fd);
@@ -483,7 +475,7 @@ int grabImage()
   return 0;
 }
 
-int writeFITS(char * filename, char errmsg[])
+int writeFITS(const char * filename, char errmsg[])
 {
   FITS_FILE* ofp;
   int i, bpp, bpsl, width, height;
@@ -495,7 +487,7 @@ int writeFITS(char * filename, char errmsg[])
   ofp = fits_open (filename, "w");
   if (!ofp)
   {
-    sprintf(errmsg, "Error: cannot open file for writing.");
+    snprintf(errmsg, ERRMSG_SIZE, "Error: cannot open file for writing.");
     return (-1);
   }
   
@@ -508,12 +500,12 @@ int writeFITS(char * filename, char errmsg[])
   hdu = create_fits_header (ofp, width, height, bpp);
   if (hdu == NULL)
   {
-     sprintf(errmsg, "Error: creating FITS header failed.");
+     snprintf(errmsg, ERRMSG_SIZE, "Error: creating FITS header failed.");
      return (-1);
   }
   if (fits_write_header (ofp, hdu) < 0)
   {
-    sprintf(errmsg, "Error: writing to FITS header failed.");
+    snprintf(errmsg, ERRMSG_SIZE, "Error: writing to FITS header failed.");
     return (-1);
   }
   
@@ -532,7 +524,7 @@ int writeFITS(char * filename, char errmsg[])
   
   if (ferror (ofp->fp))
   {
-    sprintf(errmsg, "Error: write error occured");
+    snprintf(errmsg, ERRMSG_SIZE, "Error: write error occured");
     return (-1);
   }
  
@@ -542,7 +534,7 @@ int writeFITS(char * filename, char errmsg[])
  ExposeTimeNP.s = IPS_OK;
  /*IDSetSwitch(&ExposeSP, "FITS image written to %s", filename);
  IDLog("FITS image written to '%s'\n", filename);*/
- IDSetNumber(&ExposeTimeNP, "Loading FITS image...");
+ IDSetNumber(&ExposeTimeNP, NULL);
  IDLog("Loading FITS image...\n");
  
  uploadFile(filename);
@@ -572,6 +564,7 @@ void getBasicData()
   ImageSizeN[1].min = ymin;
   ImageSizeN[1].max = ymax;
   
+  IUUpdateMinMax(&ImageSizeNP);
   IDSetNumber(&ImageSizeNP, NULL);
   
   strncpy(camNameT[0].text, getDeviceName(), MAXINDILABEL);
@@ -730,7 +723,7 @@ FITS_HDU_LIST * create_fits_header (FITS_FILE *ofp, uint width, uint height, uin
  hdulist->used.bscale = 1;
  hdulist->bscale = 1.0;
  
- sprintf(expose_s, "EXPOSURE= %d / milliseconds", V4LFrame->expose);
+ snprintf(expose_s, sizeof(expose_s), "EXPOSURE= %d / milliseconds", V4LFrame->expose);
  
  fits_add_card (hdulist, expose_s);
  fits_add_card (hdulist, instrumentName);
@@ -739,11 +732,14 @@ FITS_HDU_LIST * create_fits_header (FITS_FILE *ofp, uint width, uint height, uin
  return (hdulist);
 }
 
+
 void updateStream(void *p)
 {
+ 
    int width  = getWidth();
    int height = getHeight();
-   unsigned int totalBytes, compressedBytes = 0;
+   uLongf compressedBytes = 0;
+   uLong  totalBytes;
    unsigned char *targetFrame;
    char frameSize[FRAME_ILEN];
    int nr=0, n=0,r, frameLen;
@@ -759,17 +755,18 @@ void updateStream(void *p)
    
    /* Compress frame */
    V4LFrame->compressedFrame = (unsigned char *) realloc (V4LFrame->compressedFrame, sizeof(unsigned char) * totalBytes + totalBytes / 64 + 16 + 3);
-   r = lzo1x_1_compress(targetFrame,totalBytes,V4LFrame->compressedFrame,&compressedBytes,wrkmem);
-   if (r != LZO_E_OK)
-      //IDLog("compressed %lu bytes into %lu bytes\n", (long) totalBytes, (long) compressedBytes);
-   //else
+   
+   compressedBytes = sizeof(unsigned char) * totalBytes + totalBytes / 64 + 16 + 3;
+   
+   r = compress2(V4LFrame->compressedFrame, &compressedBytes, targetFrame, totalBytes, VIDEO_COMPRESSION_LEVEL);
+   if (r != Z_OK)
    {
  	/* this should NEVER happen */
  	IDLog("internal error - compression failed: %d\n", r);
 	return;
    }
    
-   snprintf(frameSize, FRAME_ILEN, "<Data type='VIDEO' size='%d' compsize='%d' />", totalBytes, compressedBytes);
+   snprintf(frameSize, FRAME_ILEN, "<Data type='VIDEO' size='%ld' compsize='%ld' />", totalBytes, compressedBytes);
    //snprintf(frameSize, FRAME_ILEN, "VIDEO,%d,%d\n", totalBytes, compressedBytes);
    frameLen = strlen(frameSize);
    r = 0;
@@ -810,16 +807,19 @@ void updateStream(void *p)
   
   if (streamTimerID != -1)
     	streamTimerID = addTimer(1000/ (int) FrameRateN[0].value, updateStream, NULL);
-   
+ 
 }
 
-void uploadFile(char * filename)
+void uploadFile(const char * filename)
 {
+   
    FILE * fitsFile;
    char frameSize[FRAME_ILEN];
    unsigned char *fitsData;
    int n=0, i=0, r=0;
-   unsigned int totalBytes, compressedBytes = 0, frameLen =0 , nr = 0;
+   unsigned int frameLen =0 , nr = 0;
+   uLong  totalBytes;
+   uLongf compressedBytes = 0;
    struct stat stat_p; 
  
    if ( -1 ==  stat (filename, &stat_p))
@@ -850,17 +850,19 @@ void uploadFile(char * filename)
    
    /* #2 Compress it */
    V4LFrame->compressedFrame = (unsigned char *) realloc (V4LFrame->compressedFrame, sizeof(unsigned char) * totalBytes + totalBytes / 64 + 16 + 3);
-   r = lzo1x_1_compress(fitsData, totalBytes, V4LFrame->compressedFrame, &compressedBytes, wrkmem);
-   if (r != LZO_E_OK)
-      //IDLog("compressed %lu bytes into %lu bytes\n", (long) totalBytes, (long) compressedBytes);
-   //else
+   
+    compressedBytes = sizeof(unsigned char) * totalBytes + totalBytes / 64 + 16 + 3;
+     
+     
+   r = compress2(V4LFrame->compressedFrame, &compressedBytes, fitsData, totalBytes, 9);
+   if (r != Z_OK)
    {
  	/* this should NEVER happen */
  	IDLog("internal error - compression failed: %d\n", r);
 	return;
    }
    
-   snprintf(frameSize, FRAME_ILEN, "<Data type='FITS' size='%d' compsize='%d' />", totalBytes, compressedBytes);
+   snprintf(frameSize, FRAME_ILEN, "<Data type='FITS' size='%ld' compsize='%ld' />", totalBytes, compressedBytes);
    //snprintf(frameSize, FRAME_ILEN, "FITS,%d,%d\n", totalBytes, compressedBytes);
    frameLen = strlen(frameSize);
    r = 0;
