@@ -43,7 +43,7 @@ KSPopupMenu::~KSPopupMenu()
 }
 
 void KSPopupMenu::createEmptyMenu( SkyObject *nullObj ) {
-	initPopupMenu( nullObj, i18n( "Empty sky" ), QString::null, QString::null, true, true, false );
+	initPopupMenu( nullObj, i18n( "Empty sky" ), QString::null, QString::null, true, true, false, false, false, true, false );
 
 	insertItem( i18n( "First Generation Digitized Sky Survey", "Show 1st-Gen DSS Image" ), ksw->map(), SLOT( slotDSS() ) );
 	insertItem( i18n( "Second Generation Digitized Sky Survey", "Show 2nd-Gen DSS Image" ), ksw->map(), SLOT( slotDSS2() ) );
@@ -162,22 +162,32 @@ bool KSPopupMenu::addINDI(void)
 	{
 	   for (prop = grp->pl.first(); prop != NULL; prop = grp->pl.next())
 	   {
-	     // Only std are allowed to show. Movement is somewhat problematic due to an issue with the LX200 telescopes (the telescope
-	     // does not update RA/DEC while moving N/W/E/S) so it's better off the skymap. It's avaiable in the INDI control panel nonetheless.
+	     /* Only std are allowed to show. Movement is somewhat problematic due to an issue with the LX200 telescopes (the telescope does not update RA/DEC while moving N/W/E/S) so it's better off the skymap. It's avaiable in the INDI control panel nonetheless.
+	     EXPOSE_DURATION is an INumber property, but it's so common that it's better to include in the context menu */
+	     
 	     if (prop->stdID == -1 || prop->stdID == MOVEMENT) continue;
 	     // Only switches are shown
- 	     if (prop->guitype != PG_BUTTONS && prop->guitype != PG_RADIO) continue;
+ 	     if (prop->guitype != PG_BUTTONS && prop->guitype != PG_RADIO && prop->stdID !=EXPOSE_DURATION) continue;
 	   
 	     menuDevice->insertSeparator();
 
 	     prop->assosiatedPopup = menuDevice;
-
+	     
+	     if (prop->stdID == EXPOSE_DURATION)
+	     {
+	       menuDevice->insertItem (prop->label, id);
+	       menuDevice->setItemChecked(id, false);
+	       //kdDebug() << "Expose ID: " << id << endl;
+	       id++;
+	     }
+	     else
+	     {
 	     for (element = prop->el.first(); element != NULL; element = prop->el.next(), id++)
              {
 		menuDevice->insertItem (element->label, id);
 	 	if (element->state == PS_ON)
 		{
-		        // Slew, Track, Sync are never checked in the skymap
+		        // Slew, Track, Sync, Exppse are never checked in the skymap
 			if ((element->name != "SLEW") && (element->name != "TRACK") &&
 			    (element->name != "SYNC"))
 		  		menuDevice->setItemChecked(id, true);
@@ -186,6 +196,9 @@ bool KSPopupMenu::addINDI(void)
 		}
 	 	else
 	        	menuDevice->setItemChecked(id, false);
+			
+		//kdDebug() << element->name << " ID is " << id << endl;
+	     }
 	     }
 
 	     QObject::connect(menuDevice, SIGNAL(activated(int)), prop, SLOT (convertSwitch(int)));
@@ -199,9 +212,10 @@ bool KSPopupMenu::addINDI(void)
 }
 
 void KSPopupMenu::initPopupMenu( SkyObject *obj, QString s1, QString s2, QString s3,
-	bool showRiseSet, bool showCenterTrack, bool showDetails, bool showTrail, bool addTrail, bool showAngularDistance ) {
+		bool showRiseSet, bool showCenterTrack, bool showDetails, bool showTrail, bool addTrail, 
+		bool showAngularDistance, bool showObsList ) {
+	
 	clear();
-
 	if ( s1.isEmpty() ) s1 = i18n( "Empty sky" );
 
 	bool showLabel( true );
@@ -210,9 +224,8 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, QString s1, QString s2, QString
 	pmTitle = new QLabel( s1, this );
 	pmTitle->setAlignment( AlignCenter );
 	QPalette pal( pmTitle->palette() );
-	pal.setColor( QPalette::Normal, QColorGroup::Background, QColor( "White" ) );
-	pal.setColor( QPalette::Normal, QColorGroup::Foreground, QColor( "Black" ) );
-	pal.setColor( QPalette::Inactive, QColorGroup::Foreground, QColor( "Black" ) );
+	pal.setColor( QPalette::Normal, QColorGroup::Background, pal.color( QPalette::Normal, QColorGroup::Base ) );
+	pal.setColor( QPalette::Normal, QColorGroup::Foreground, pal.color( QPalette::Normal, QColorGroup::Text ) );
 	pmTitle->setPalette( pal );
 	insertItem( pmTitle );
 
@@ -230,6 +243,12 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, QString s1, QString s2, QString
 		insertItem( pmType );
 	}
 
+	QString c = obj->constellation( ksw->data()->csegmentList, ksw->data()->cnameList );
+	pmConstellation = new QLabel( c, this );
+	pmConstellation->setAlignment( AlignCenter );
+	pmConstellation->setPalette( pal );
+	insertItem( pmConstellation );
+	
 	//Insert Rise/Set/Transit labels
 	if ( showRiseSet && obj ) {
 		pmRiseTime = new QLabel( i18n( "Rise time: 00:00" ), this );
@@ -285,6 +304,13 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, QString s1, QString s2, QString
 		}
 	}
 
+	if ( showObsList && obj ) {
+		if ( ksw->observingList()->contains( obj ) )
+			insertItem( i18n("Remove From List"), ksw->observingList(), SLOT( slotRemoveObject() ) );
+		else 
+			insertItem( i18n("Add to List"), ksw->observingList(), SLOT( slotAddObject() ) );
+	}
+	
 	if ( showTrail && obj && obj->isSolarSystem() ) {
 		if ( addTrail ) {
 			insertItem( i18n( "Add Trail" ), ksw->map(), SLOT( slotAddPlanetTrail() ) );
