@@ -54,9 +54,10 @@ void SkyMap::resizeEvent( QResizeEvent * )
 void SkyMap::keyPressEvent( QKeyEvent *e ) {
 	QString s;
 	bool arrowKeyPressed( false );
+	bool shiftPressed( false );
 	float step = 1.0;
-	if ( e->state() & ShiftButton ) step = 10.0;
-
+	if ( e->state() & ShiftButton ) { step = 10.0; shiftPressed = true; }
+	
 	//If the DCOP resume key was pressed, we process it here
 	if ( ! data->resumeKey.isNull() && e->key() == data->resumeKey.keyCodeQt() ) {
 		//kdDebug() << "resumeKey pressed; resuming DCOP." << endl;
@@ -248,16 +249,64 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 			data->clock()->manualTick( true );
 			data->clock()->setScale( -1.0 * data->clock()->scale() ); //reset original sign of time step
 			update();
+			kapp->processEvents();
 			break;
 
 		case Key_Period: //advance one step forward in time
+		case Key_Greater:
 			if ( data->clock()->isActive() ) data->clock()->stop();
 			data->clock()->manualTick( true );
 			update();
+			kapp->processEvents();
 			break;
 
+			//FIXME: Uncomment after feature thaw!
+//		case Key_C: //Center clicked object object
+//			if ( clickedObject() ) slotCenter();
+//			break;
+
+		case Key_D: //Details window for Clicked/Centered object
+			if ( shiftPressed ) setClickedObject( focusObject() );
+			if ( clickedObject() ) slotDetail();
+			break;
+
+		case Key_P: //Show Popup menu for Clicked/Centered object
+			if ( shiftPressed ) setClickedObject( focusObject() );
+			if ( clickedObject() ) 
+				clickedObject()->showPopupMenu( pmenu, QCursor::pos() );
+			break;
+
+		case Key_O: //Add object to Observing List
+			if ( shiftPressed ) setClickedObject( focusObject() );
+			if ( clickedObject() ) 
+				ksw->observingList()->slotAddObject();
+			break;
+
+		case Key_L: //Toggle User label on Clicked/Centered object
+			if ( shiftPressed ) setClickedObject( focusObject() );
+			if ( clickedObject() ) {
+				if ( isObjectLabeled( clickedObject() ) )
+					slotRemoveObjectLabel();
+				else 
+					slotAddObjectLabel();
+			}
+			break;
+
+		case Key_T: //Toggle planet trail on Clicked/Centered object (if solsys) 
+			if ( shiftPressed ) setClickedObject( focusObject() );
+			if ( clickedObject() && clickedObject()->isSolarSystem() ) {
+				if ( ((KSPlanetBase*)clickedObject())->hasTrail() )
+					slotRemovePlanetTrail();
+				else 
+					slotAddPlanetTrail();
+			}
+			break;
+
+
+
 //TIMING
-		case Key_T: //loop through all objects, get Sin, Cos, Rad
+/*
+		case Key_G: //loop through all cities
 		{
 
       QFile file;
@@ -271,7 +320,6 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
         }
       }
 
-/*
 			QTime t1;
 			t1.start();
       for (int i=0;i<10;i++) {
@@ -328,9 +376,9 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
       }
 			kdDebug() << "time taken for reading deep sky data old code  (1 times): (msec): " << t4.elapsed() << endl;
 
-*/
 			break;
 		}
+*/
 
 //END_TIMING
 	}
@@ -394,20 +442,6 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		HoverTimer.start( HOVER_INTERVAL, true );
 	}
 	
-	// Are we in angularDistanceMode?: Then draw a line
-	if ( isAngleMode() ) {
-
-		// We put this instruction here so that the first point of the 
-		// ruler is recomputed when moving the mouse. The initial 
-		// point of the ruler may change if the time step is high.
-
-		if ( Options::useAltAz() ) PreviousClickedPoint.EquatorialToHorizontal( data->LST, data->geo()->lat() );
-		beginRulerPoint = getXY( previousClickedPoint(), Options::useAltAz(), Options::useRefraction() );
-
-		endRulerPoint =  QPoint(e->x(), e->y());
-	}
-		
-	
 	//Are we dragging an infoBox?
 	if ( infoBoxes()->dragBox( e ) ) {
 		update();
@@ -448,7 +482,7 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 	if (unusablePoint (dx, dy)) return;	// break if point is unusable
 
 	//determine RA, Dec of mouse pointer
-	setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() ) );
+	setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat(), Options::useRefraction() ) );
 	mousePoint()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 
 
@@ -512,7 +546,7 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		data->HourAngle->setH( dHA );
 
 		//redetermine RA, Dec of mouse pointer, using new focus
-		setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() ) );
+		setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat(), Options::useRefraction() ) );
 		setClickedPoint( mousePoint() );
 
 		forceUpdate();  // must be new computed
@@ -552,7 +586,7 @@ void SkyMap::mouseReleaseEvent( QMouseEvent * ) {
 		double dx = ( 0.5*width()  - ZoomRect.center().x() )/Options::zoomFactor();
 		double dy = ( 0.5*height() - ZoomRect.center().y() )/Options::zoomFactor();
 
-		SkyPoint newcenter = dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() );
+		SkyPoint newcenter = dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat(), Options::useRefraction() );
 		setClickedPoint( &newcenter );
 		setClickedObject( NULL );
 		setFocusObject( NULL );
