@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: DocPropLangDlg.cpp,v 1.12 2003/07/17 12:48:20 binner Exp $
-
                    document language dialog class
 
     -----------------------------------------------------------------------
@@ -30,18 +28,13 @@
 #include "DocPropLangDlg.h"
 #include "LangPropPage.h"
 
-#include <kv_resource.h>
 #include <kvoctraindoc.h>
 #include <langset.h>
 
-#include <rowtable.h>
-
 #include <kapplication.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include <qcombobox.h>
-#include <qpixmap.h>
 
 #define Inherited QTabDialog
 
@@ -98,8 +91,6 @@ DocPropsLangDlg::DocPropsLangDlg
 
   connect( this, SIGNAL(applyButtonPressed()), SLOT(okButton()) );
   connect( this, SIGNAL(cancelButtonPressed()), SLOT(cancelButton()) );
-
-  setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
 }
 
 
