@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: SimpleQueryDlg.cpp,v 1.20 2004/03/07 18:36:11 annma Exp $
-
                        query dialog for properties
 
     -----------------------------------------------------------------------
@@ -10,6 +8,7 @@
 
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
+                           (C) 2004 Peter Hedlund
     email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
@@ -37,6 +36,7 @@
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
+#include <kprogress.h>
 
 SimpleQueryDlg::SimpleQueryDlg(
         QueryType querytype,
@@ -73,7 +73,8 @@ SimpleQueryDlg::SimpleQueryDlg(
    setQuery (querytype, entry, column,
              q_cycle, q_num, q_start,
              exp, doc, mqtime, showcounter, type_to);
-   setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
+   countbar->setFormat("%v/%m");
+   timebar->setFormat("%v");
 }
 
 
@@ -167,8 +168,8 @@ void SimpleQueryDlg::setQuery(QueryType _querytype,
    s.setNum (q_cycle);
    progCount->setText (s);
 
-   countbar->setData (q_start, q_start-q_num+1, true);
-   countbar->repaint();
+   countbar->setTotalSteps(q_start);
+   countbar->setProgress(q_start - q_num + 1);
 
    if (mqtime >= 1000) { // more than 1000 milli-seconds
      if (qtimer == 0) {
@@ -178,8 +179,8 @@ void SimpleQueryDlg::setQuery(QueryType _querytype,
 
      if (type_timeout != kvq_notimeout) {
        timercount = mqtime/1000;
-       timebar->setData (timercount, timercount, false);
-       timebar->repaint();
+       timebar->setTotalSteps(timercount);
+       timebar->setProgress(timercount);
        qtimer->start(1000, TRUE);
      }
      else
@@ -202,14 +203,12 @@ void SimpleQueryDlg::timeoutReached()
 {
    if (timercount > 0) {
      timercount--;
-     timebar->setData (-1, timercount, false);
-     timebar->repaint();
+     timebar->setProgress(timercount);
      qtimer->start(1000, TRUE);
    }
 
    if (timercount <= 0) {
-     timebar->setData (-1, 0, false);
-     timebar->repaint();
+     timebar->setProgress(0);
      if (type_timeout == kvq_show ) {
        showAllClicked();
        dont_know->setDefault(true);
@@ -309,7 +308,7 @@ void SimpleQueryDlg::editClicked()
      break;
 
      default:
-       ;      
+       ;
    }
 }
 
@@ -321,7 +320,7 @@ void SimpleQueryDlg::keyPressEvent( QKeyEvent *e )
     case Key_Escape:
       dontKnowClicked();
     break;
-      
+
     case Key_Return:
     case Key_Enter:
       if (dont_know->isDefault() )
@@ -333,7 +332,7 @@ void SimpleQueryDlg::keyPressEvent( QKeyEvent *e )
       else if (verify->isDefault() )
         verifyClicked();
     break;
-      
+
     default:
       e->ignore();
     break;
